# -*- coding: utf-8 -*-
"""Provides specific functions for instruments and classes of instruments.

Each set of methods is contained within a subpackage of this set.
"""

from pysat.instruments.templates import template_instrument

__all__ = ['template_instrument']
